use new sdbus++ camelcase

Change I17a8d7479556596a3cf252b3f4eae9c8df547189 will change
how sdbus++ generates names which start with an acronym.
Prepare for this by keying off the SDBUSPP_NEW_CAMELCASE
define to use the new format.

Changes:
    vSPString -> vspString

Signed-off-by: Patrick Williams <patrick@stwcx.xyz>
Change-Id: Idec24c3e2d58abca39fe236051f28567b626e260
diff --git a/dump-extensions/openpower-dumps/resource_dump_entry.hpp b/dump-extensions/openpower-dumps/resource_dump_entry.hpp
index 19d2674..783ec94 100644
--- a/dump-extensions/openpower-dumps/resource_dump_entry.hpp
+++ b/dump-extensions/openpower-dumps/resource_dump_entry.hpp
@@ -8,6 +8,10 @@
 
 #include <chrono>
 
+#ifndef SDBUSPP_NEW_CAMELCASE
+#define vspString vSPString
+#endif
+
 namespace openpower
 {
 namespace dump
@@ -46,14 +50,14 @@
      *             since the epoch.
      *  @param[in] dumpSize - Dump size in bytes.
      *  @param[in] sourceId - DumpId provided by the source.
      *  @param[in] vspString - Input to host to generate the resource dump.
      *  @param[in] pwd - Password needed by host to validate the request.
      *  @param[in] status - status  of the dump.
      *  @param[in] parent - The dump entry's parent.
      */
     Entry(sdbusplus::bus::bus& bus, const std::string& objPath, uint32_t dumpId,
           uint64_t timeStamp, uint64_t dumpSize, const uint32_t sourceId,
-          std::string vspString, std::string pwd,
+          std::string vspStr, std::string pwd,
           phosphor::dump::OperationStatus status,
           phosphor::dump::Manager& parent) :
         EntryIfaces(bus, objPath.c_str(), true),
@@ -61,7 +65,7 @@
                               status, parent)
     {
         sourceDumpId(sourceId);
-        vSPString(vspString);
+        vspString(vspStr);
         password(pwd);
         // Emit deferred signal.
         this->openpower::dump::resource::EntryIfaces::emit_object_added();
@@ -46,14 +50,14 @@
      *  @param[in] dumpSize - Dump size in bytes.
      *  @param[in] sourceId - DumpId provided by the source.
-     *  @param[in] vspString - Input to host to generate the resource dump.
+     *  @param[in] vspStr- Input to host to generate the resource dump.
      *  @param[in] pwd - Password needed by host to validate the request.
      *  @param[in] status - status  of the dump.